@@ -4,7 +4,8 @@
 #' A series of basic function for the API lookup.
 #' @param ID The member ID value. If empty, function calls \code{\link{mnis_all_members}} and returns basic information on all members of both houses.
 #' @param ref_dods Request based on the DODS membership ID scheme. Defaults to FALSE, where it requests data based on the default membership ID scheme.
-#' @param tidy Fix the variable names in the tibble to remove non-alphanumeric characters and superfluous text. Defaults to TRUE.
+#' @param tidy If TRUE, fixes the variable names in the tibble to remove non-alphanumeric characters and superfluous text, and convert to a consistent style. Defaults to TRUE.
+#' @param tidy_style The style to convert variable names to, if tidy=TRUE. Accepts one of "snake_case", "camelCase" and "period.case". Defaults to "snake_case".
 #' @keywords mnis
 #' @return A tibble with the data corresponding to the particular function called.
 #' @examples \dontrun{
@@ -26,7 +27,7 @@
 
 mnis_additional <- function() {
 
-    x <- c("mnis_full_biog()", "mnis_basic_details()", "mnis_biography_entries()", "mnis_committees()", "mnis_addresses()", "mnis_constituencies()", "mnis_elections_contested()", "mnis_experiences()", "mnis_government_posts()", "mnis_honours()", "mnis_house_memberships()", "mnis_statuses()", "mnis_staff()", "mnis_interests()", "mnis_knownas()", "mnis_maiden_speeches()", "mnis_opposition_posts()", "mnis_other_parliaments()", "mnis_parliamentary_posts()", "mnis_parties()", "mnis_preferred_names()")
+    x <- c("mnis_full_biog()", "mnis_basic_details()", "mnis_biography_entries()", "mnis_committees()", "mnis_addresses()", "mnis_constituencies()", "mnis_elections_contested()", "mnis_experiences()", "mnis_government_posts()", "mnis_honours()", "mnis_house_memberships()", "mnis_statuses()", "mnis_staff()", "mnis_interests()", "mnis_known_as()", "mnis_maiden_speeches()", "mnis_opposition_posts()", "mnis_other_parliaments()", "mnis_parliamentary_posts()", "mnis_parties()", "mnis_preferred_names()")
     message("All Available Additional Information Functions:")
 
     print(x)
@@ -35,7 +36,7 @@ mnis_additional <- function() {
 
 #' @export
 #' @rdname mnis_additional
-mnis_basic_details <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_basic_details <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -59,7 +60,7 @@ mnis_basic_details <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -79,7 +80,7 @@ mnis_basic_details <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -94,7 +95,7 @@ mnis_basic_details <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_biography_entries <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_biography_entries <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -118,7 +119,7 @@ mnis_biography_entries <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -137,7 +138,7 @@ mnis_biography_entries <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -151,7 +152,7 @@ mnis_biography_entries <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_committees <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_committees <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -175,7 +176,7 @@ mnis_committees <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -195,7 +196,7 @@ mnis_committees <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -209,7 +210,7 @@ mnis_committees <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_addresses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_addresses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -233,7 +234,7 @@ mnis_addresses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -253,7 +254,7 @@ mnis_addresses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -267,7 +268,7 @@ mnis_addresses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_constituencies <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_constituencies <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -291,7 +292,7 @@ mnis_constituencies <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -311,7 +312,7 @@ mnis_constituencies <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -324,7 +325,7 @@ mnis_constituencies <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 }
 #' @export
 #' @rdname mnis_additional
-mnis_elections_contested <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_elections_contested <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -348,7 +349,7 @@ mnis_elections_contested <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -368,7 +369,7 @@ mnis_elections_contested <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -382,7 +383,7 @@ mnis_elections_contested <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_experiences <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_experiences <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -406,7 +407,7 @@ mnis_experiences <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -426,7 +427,7 @@ mnis_experiences <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -440,7 +441,7 @@ mnis_experiences <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_government_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_government_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -464,7 +465,7 @@ mnis_government_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -484,7 +485,7 @@ mnis_government_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -498,7 +499,7 @@ mnis_government_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_honours <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_honours <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -522,7 +523,7 @@ mnis_honours <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -542,7 +543,7 @@ mnis_honours <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -556,7 +557,7 @@ mnis_honours <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_house_memberships <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_house_memberships <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -580,7 +581,7 @@ mnis_house_memberships <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -600,7 +601,7 @@ mnis_house_memberships <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -614,7 +615,7 @@ mnis_house_memberships <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_statuses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_statuses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -638,7 +639,7 @@ mnis_statuses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -658,7 +659,7 @@ mnis_statuses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -673,7 +674,7 @@ mnis_statuses <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_staff <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_staff <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -697,7 +698,7 @@ mnis_staff <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -717,7 +718,7 @@ mnis_staff <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -731,7 +732,7 @@ mnis_staff <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -755,7 +756,7 @@ mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -769,11 +770,13 @@ mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
         x <- t(x)
 
+        x <- tibble::as_tibble(x)
+
     }
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -786,7 +789,7 @@ mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 }
 #' @export
 #' @rdname mnis_additional
-mnis_known_as <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_known_as <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -810,7 +813,7 @@ mnis_known_as <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -830,7 +833,7 @@ mnis_known_as <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -844,7 +847,7 @@ mnis_known_as <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
 #' @export
 #' @rdname mnis_additional
-mnis_maiden_speeches <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_maiden_speeches <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -868,7 +871,7 @@ mnis_maiden_speeches <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -888,7 +891,7 @@ mnis_maiden_speeches <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -903,7 +906,7 @@ mnis_maiden_speeches <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_opposition_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_opposition_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -927,7 +930,7 @@ mnis_opposition_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -947,7 +950,7 @@ mnis_opposition_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -962,7 +965,7 @@ mnis_opposition_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_other_parliaments <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_other_parliaments <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -986,7 +989,7 @@ mnis_other_parliaments <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -1006,7 +1009,7 @@ mnis_other_parliaments <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -1019,7 +1022,7 @@ mnis_other_parliaments <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 }
 #' @export
 #' @rdname mnis_additional
-mnis_parliamentary_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_parliamentary_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -1043,7 +1046,7 @@ mnis_parliamentary_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -1063,7 +1066,7 @@ mnis_parliamentary_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -1078,7 +1081,7 @@ mnis_parliamentary_posts <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_parties <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_parties <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -1102,7 +1105,7 @@ mnis_parties <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -1122,7 +1125,7 @@ mnis_parties <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
@@ -1136,7 +1139,7 @@ mnis_parties <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 #' @export
 #' @rdname mnis_additional
 
-mnis_preferred_names <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
+mnis_preferred_names <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style="snake_case") {
 
     if (missing(ID)) {
         x <- mnis_all_members()
@@ -1160,7 +1163,7 @@ mnis_preferred_names <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
             stop("API did not return json", call. = FALSE)
         }
 
-        got <- tidy_bom(got)
+        got <- mnis::tidy_bom(got)
 
         got <- jsonlite::fromJSON(got, flatten = TRUE)
 
@@ -1180,7 +1183,7 @@ mnis_preferred_names <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE) {
 
     if (tidy == TRUE) {
 
-        x <- mnis_tidy(x)
+        x <- mnis::mnis_tidy(x, tidy_style)
 
         x
 
